@@ -11,6 +11,7 @@ from text_embeddings.hash.util import murmurhash
 from text_embeddings.base import EmbeddingTokenizer
 from loguru import logger
 
+
 class CANINETokenizer(EmbeddingTokenizer):
     """
     A character hashing tokenizer/embedder from [CANINE: Pre-training an Efficient Tokenization-Free Encoder for Language Representation](https://arxiv.org/abs/2103.06874)
@@ -49,11 +50,13 @@ class CANINETokenizer(EmbeddingTokenizer):
         self.max_length = max_length
 
         if self.model_input_names is None:
-            logger.warning('Using default model_input_names values ["input_ids", "token_type_ids", "attention_mask"]')
+            logger.warning(
+                'Using default model_input_names values ["input_ids", "token_type_ids", "attention_mask"]'
+            )
             self.model_input_names = ["input_ids", "token_type_ids", "attention_mask"]
 
     def text2embeddings(self, text: str) -> np.ndarray:
-        """Convert text into an numpy array, in (sequence_length, 1, hash_size) shape.
+        """Convert text into an numpy array, in (sequence_length, hash_size) shape.
 
         Parameters
         ----------
@@ -63,17 +66,17 @@ class CANINETokenizer(EmbeddingTokenizer):
         Returns
         -------
         np.ndarray
-            An array in (sequence_length, 1, hash_size) shape
+            An array in (sequence_length, hash_size) shape
         """
         if not text:
             return None
-        
+
         result = np.zeros((len(text), self.hash_size))
         for i, char in enumerate(text):
-            result[i] = murmurhash(char, feature_size=self.hash_size*2)
-    
+            result[i] = murmurhash(char, feature_size=self.hash_size * 2)
+
         return result
-    
+
     def create_padding_token_embedding(self, input_embeddings=None) -> np.ndarray:
         """Create a padding token embedding.
 
@@ -87,4 +90,4 @@ class CANINETokenizer(EmbeddingTokenizer):
         np.ndarray
             An embedding array in (hash_size)
         """
-        return np.zeros((self.hash_size, ))
+        return np.zeros((self.hash_size,))
